/***************************************************************************
 *   Copyright (C) 2005 by Christian Hubinger   *
 *   e9806056@student.tuwien.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#ifndef MAINWIDGET_H
#define MAINWIDGET_H

#include "mainwidget_designer.h"

class Details;


class MainWidget : public MainWidgetDesigner
{
  TQ_OBJECT
  

public:
  MainWidget(TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
  ~MainWidget();
  /*$PUBLIC_FUNCTIONS$*/

public slots:
	void slotSetRunningStatus( bool );
	void slotDetailsClosed();

protected:
  /*$PROTECTED_FUNCTIONS$*/

protected slots:
  /*$PROTECTED_SLOTS$*/

private slots:
	void slotShowDetails();

private:
	Details *m_wid_details;


signals:
	void sigQueryDetails( bool );
	void sigUpdateRuleCount( const TQString&, const TQString&, int );
};

#endif

